==> piwigo-2.1.6.zip: piwigo/plugins/LocalFilesEditor/language/en_UK/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Local config';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_onglet_lang'] = 'Languages';
$lang['locfiledit_onglet_plug'] = 'Personal Plugin';
$lang['locfiledit_cant_save'] = 'Current file isn\'t writeable. Check if a directory "local/" is writeable (chmod).';
$lang['locfiledit_newfile'] = 'File is not existing and will be created by LocalFiles Editor';
$lang['locfiledit_save_config'] = 'File written successfully.';
$lang['locfiledit_show_default'] = 'Display reference file: ';
$lang['locfiledit_save_bak'] = 'Backup copy will be created on save.';
$lang['locfiledit_saved_bak'] = 'Backup file created (%s)';
$lang['locfiledit_save_file'] = 'Save file';
$lang['locfiledit_choose_file'] = 'Choose the file to be edited';
$lang['locfiledit_edit'] = 'Edit';
$lang['locfiledit_restore'] = 'Restore the backup file';
$lang['locfiledit_restore_confirm'] = 'Please confirm?
Restore won\'t be effective till next save.';
$lang['locfiledit_bak_loaded1'] = 'Backup file loaded.';
$lang['locfiledit_bak_loaded2'] = 'You must save file to restore it.';
$lang['locfiledit_syntax_error'] = 'Syntax error! File can\'t be saved.';
$lang['locfiledit_enable_editarea'] = 'Enable Editarea';
$lang['locfiledit_disable_editarea'] = 'Disable Editarea';
$lang['locfiledit_new_tpl'] = 'Create new file';
$lang['locfiledit_new_filename'] = 'File name';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Empty page';
$lang['locfiledit_parent_directory'] = 'Parent directory';
$lang['locfiledit_filename_error'] = 'Forbidden characters in file name.';
$lang['locfiledit_file_already_exists'] = 'File already exists.';
$lang['locfiledit_model_error'] = 'You must choose a model.';
$lang['locfiledit_empty_filename'] = 'You must fill file name.';
$lang['locfiledit_webmaster_only'] = 'Only webmasters can create or modify local files.';

?>

==> piwigo-2.2.4.zip: piwigo/plugins/LocalFilesEditor/language/en_UK/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Local config';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_onglet_lang'] = 'Languages';
$lang['locfiledit_onglet_plug'] = 'Personal Plugin';
$lang['locfiledit_cant_save'] = 'Current file isn\'t writeable. Check if a directory "local/" is writeable (chmod).';
$lang['locfiledit_newfile'] = 'File is not existing and will be created by LocalFiles Editor';
$lang['locfiledit_save_config'] = 'File written successfully.';
$lang['locfiledit_show_default'] = 'Display reference file: ';
$lang['locfiledit_save_bak'] = 'Backup copy will be created on save.';
$lang['locfiledit_saved_bak'] = 'Backup file created (%s)';
$lang['locfiledit_save_file'] = 'Save file';
$lang['locfiledit_choose_file'] = 'Choose the file to be edited';
$lang['locfiledit_edit'] = 'Edit';
$lang['locfiledit_restore'] = 'Restore the backup file';
$lang['locfiledit_restore_confirm'] = 'Please confirm?
Restore won\'t be effective till next save.';
$lang['locfiledit_bak_loaded1'] = 'Backup file loaded.';
$lang['locfiledit_bak_loaded2'] = 'You must save file to restore it.';
$lang['locfiledit_syntax_error'] = 'Syntax error! File can\'t be saved.';
$lang['locfiledit_new_tpl'] = 'Create new file';
$lang['locfiledit_new_filename'] = 'File name';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Empty page';
$lang['locfiledit_parent_directory'] = 'Parent directory';
$lang['locfiledit_filename_error'] = 'Forbidden characters in file name.';
$lang['locfiledit_file_already_exists'] = 'File already exists.';
$lang['locfiledit_model_error'] = 'You must choose a model.';
$lang['locfiledit_empty_filename'] = 'You must fill file name.';
$lang['locfiledit_webmaster_only'] = 'Only webmasters can create or modify local files.';
?>
